@@ -14,6 +14,13 @@ import tempfile
 from logging import DEBUG
 from warnings import simplefilter
 
+try:
+    import shtab
+except ImportError:
+    shtab_tag = False
+else:
+    shtab_tag = True
+
 from glances import __apiversion__, __version__, psutil_version
 from glances.config import Config
 from glances.globals import WINDOWS, disable, enable
@@ -96,10 +103,68 @@ Examples of use:
 
 """
 
-    def __init__(self):
+    def __init__(self, args_begin_at=1):
         """Manage the command line arguments."""
-        # Read the command line arguments
-        self.args = self.parse_args()
+        self.init_glances(args_begin_at)
+
+    def init_glances(self, args_begin_at):
+        """Main method to init Glances."""
+        # Read the command line arguments or parse the one given in parameter (parser)
+        self.args = self.parse_args(args_begin_at)
+
+        # Load the configuration file, if it exists
+        # This function should be called after the parse_args
+        # because the configuration file path can be defined
+        self.config = Config(self.args.conf_file)
+
+        # Init Glances debug mode
+        self.init_debug(self.args)
+
+        # Plugins Glances refresh rate
+        self.init_refresh_rate(self.args)
+
+        # Manage Plugins disable/enable option
+        self.init_plugins(self.args)
+
+        # Init Glances client/server mode
+        self.init_client_server(self.args)
+
+        # Init UI mode
+        self.init_ui_mode(self.args)
+
+        # Init the generate_graph tag
+        # Should be set to True to generate graphs
+        self.args.generate_graph = False
+
+        # Export is only available in standalone or client mode (issue #614)
+        export_tag = self.args.export is not None and any(self.args.export)
+        if WINDOWS and export_tag:
+            # On Windows, export is possible but only in quiet mode
+            # See issue #1038
+            logger.info("On Windows OS, export disable the Web interface")
+            self.args.quiet = True
+            self.args.webserver = False
+        elif not (self.is_standalone() or self.is_client()) and export_tag:
+            logger.critical("Export is only available in standalone or client mode")
+            sys.exit(2)
+
+        # Filter is only available in standalone mode
+        if not self.args.process_filter and not self.is_standalone():
+            logger.debug("Process filter is only available in standalone mode")
+
+        # Cursor option is only available in standalone mode
+        if not self.args.disable_cursor and not self.is_standalone():
+            logger.debug("Cursor is only available in standalone mode")
+
+        # Let the plugins known the Glances mode
+        self.args.is_standalone = self.is_standalone()
+        self.args.is_client = self.is_client()
+        self.args.is_client_browser = self.is_client_browser()
+        self.args.is_server = self.is_server()
+        self.args.is_webserver = self.is_webserver()
+
+        # Check mode compatibility
+        self.check_mode_compatibility()
 
     def version_msg(self):
         """Return the version message."""
@@ -117,9 +182,16 @@ Examples of use:
             formatter_class=argparse.RawDescriptionHelpFormatter,
             epilog=self.example_of_use,
         )
+        if shtab_tag:
+            shtab.add_argument_to(parser, ["--print-completion"])
         parser.add_argument('-V', '--version', action='version', version=self.version_msg())
         parser.add_argument('-d', '--debug', action='store_true', default=False, dest='debug', help='enable debug mode')
-        parser.add_argument('-C', '--config', dest='conf_file', help='path to the configuration file')
+        if shtab_tag:
+            parser.add_argument(
+                '-C', '--config', dest='conf_file', help='path to the configuration file'
+            ).complete = shtab.FILE
+        else:
+            parser.add_argument('-C', '--config', dest='conf_file', help='path to the configuration file')
         parser.add_argument('-P', '--plugins', dest='plugin_dir', help='path to additional plugin directory')
         # Disable plugin
         parser.add_argument(
@@ -307,7 +379,7 @@ Examples of use:
             default=None,
             type=str,
             dest='export_process_filter',
-            help='set the export process filter (comman separated list of regular expression)',
+            help='set the export process filter (comma-separated list of regular expression)',
         )
         # Client/Server option
         parser.add_argument(
@@ -478,7 +550,18 @@ Examples of use:
             help='test memory leak (python 3.4 or higher needed)',
         )
         parser.add_argument(
-            '--api-doc', default=None, action='store_true', dest='stdout_apidoc', help='display fields descriptions'
+            '--api-doc',
+            default=None,
+            action='store_true',
+            dest='stdout_api_doc',
+            help='display Python API documentation',
+        )
+        parser.add_argument(
+            '--api-restful-doc',
+            default=None,
+            action='store_true',
+            dest='stdout_api_restful_doc',
+            help='display Restful API documentation',
         )
         if not WINDOWS:
             parser.add_argument(
@@ -510,6 +593,13 @@ Examples of use:
             dest='diskio_iops',
             help='show IO per second in the DiskIO plugin',
         )
+        parser.add_argument(
+            '--diskio-latency',
+            action='store_true',
+            default=False,
+            dest='diskio_latency',
+            help='show IO latency in the DiskIO plugin',
+        )
         parser.add_argument(
             '--fahrenheit',
             action='store_true',
@@ -558,6 +648,22 @@ Examples of use:
             default='',
             help='strftime format string for displaying current date in standalone mode',
         )
+        # Fetch
+        parser.add_argument(
+            '--fetch',
+            '--stdout-fetch',
+            action='store_true',
+            default=False,
+            dest='stdout_fetch',
+            help='display a (neo)fetch like summary and exit',
+        )
+        parser.add_argument(
+            '--fetch-template',
+            '--stdout-fetch-template',
+            dest='fetch_template',
+            default='',
+            help='overwrite default fetch template file',
+        )
 
         return parser
 
@@ -617,7 +723,10 @@ Examples of use:
         args.network_cumul = False
 
         # Processlist is updated in processcount
-        if getattr(args, 'enable_processlist', False) or getattr(args, 'enable_programlist', False):
+        if getattr(args, 'disable_processcount', False):
+            logger.warning('Processcount is disable, so processlist (updated by processcount) is also disable')
+            disable(args, 'processlist')
+        elif getattr(args, 'enable_processlist', False) or getattr(args, 'enable_programlist', False):
             enable(args, 'processcount')
 
         # Set a default export_process_filter (with all process) when using the stdout mode
@@ -715,6 +824,10 @@ Examples of use:
             disable(args, 'memswap')
             disable(args, 'load')
 
+        # Unicode => No separator
+        if args.disable_unicode:
+            args.enable_separator = False
+
         # Memory leak
         if getattr(args, 'memory_leak', False):
             logger.info('Memory leak detection enabled')
@@ -724,72 +837,20 @@ Examples of use:
             args.time = 1
             args.disable_history = True
 
-        # Unicode => No separator
-        if args.disable_unicode:
-            args.enable_separator = False
+        # Disable history if history_size is 0
+        if self.config.has_section('global'):
+            if self.config.get_int_value('global', 'history_size', default=1200) == 0:
+                args.disable_history = True
 
-    def parse_args(self):
-        """Parse command line arguments."""
-        args = self.init_args().parse_args()
+        # Display an information message if history is disabled
+        if args.disable_history:
+            logger.info("Stats history is disabled")
 
-        # Load the configuration file, if it exists
-        # This function should be called after the parse_args
-        # because the configuration file path can be defined
-        self.config = Config(args.conf_file)
-
-        # Init Glances debug mode
-        self.init_debug(args)
-
-        # Plugins Glances refresh rate
-        self.init_refresh_rate(args)
-
-        # Manage Plugins disable/enable option
-        self.init_plugins(args)
-
-        # Init Glances client/server mode
-        self.init_client_server(args)
-
-        # Init UI mode
-        self.init_ui_mode(args)
-
-        # Init the generate_graph tag
-        # Should be set to True to generate graphs
-        args.generate_graph = False
-
-        # Control parameter and exit if it is not OK
-        self.args = args
-
-        # Export is only available in standalone or client mode (issue #614)
-        export_tag = self.args.export is not None and any(self.args.export)
-        if WINDOWS and export_tag:
-            # On Windows, export is possible but only in quiet mode
-            # See issue #1038
-            logger.info("On Windows OS, export disable the Web interface")
-            self.args.quiet = True
-            self.args.webserver = False
-        elif not (self.is_standalone() or self.is_client()) and export_tag:
-            logger.critical("Export is only available in standalone or client mode")
-            sys.exit(2)
-
-        # Filter is only available in standalone mode
-        if not args.process_filter and not self.is_standalone():
-            logger.debug("Process filter is only available in standalone mode")
-
-        # Cursor option is only available in standalone mode
-        if not args.disable_cursor and not self.is_standalone():
-            logger.debug("Cursor is only available in standalone mode")
-
-        # Let the plugins known the Glances mode
-        self.args.is_standalone = self.is_standalone()
-        self.args.is_client = self.is_client()
-        self.args.is_client_browser = self.is_client_browser()
-        self.args.is_server = self.is_server()
-        self.args.is_webserver = self.is_webserver()
-
-        # Check mode compatibility
-        self.check_mode_compatibility()
-
-        return args
+    def parse_args(self, args_begin_at):
+        """Parse command line arguments.
+        Glances args start at position args_begin_at.
+        """
+        return self.init_args().parse_args(sys.argv[args_begin_at:])
 
     def check_mode_compatibility(self):
         """Check mode compatibility"""
